[−][src]Crate actix_test_server
Various helpers for Actix applications to use during testing.
Structs
| TestServer | The |
| TestServerRuntime | Test server runstime |
Various helpers for Actix applications to use during testing.
| TestServer | The |
| TestServerRuntime | Test server runstime |